#ifndef RESNET_HPP__
#define RESNET_HPP__

#include <future>
#include <memory>
#include <string>
#include <vector>

namespace resnet{

struct Attribute {
  float confidence;
  int class_label;

  Attribute() = default;
  Attribute(float confidence, int class_label)
      : confidence(confidence),
        class_label(class_label) {}
};

struct Image {
  const void *bgrptr = nullptr;
  int width = 0, height = 0;

  Image() = default;
  Image(const void *bgrptr, int width, int height) : bgrptr(bgrptr), width(width), height(height) {}
};


class Infer {
 public:
  virtual Attribute forward(const Image &image, void *stream = nullptr) = 0;
  virtual std::vector<Attribute> forwards(const std::vector<Image> &images,
                                         void *stream = nullptr) = 0;
};

std::shared_ptr<Infer> load(const std::string &engine_file);

}

#endif